import time

def animate_print(text,delay=0.05):
    custom_text = []
    for i in text:
        custom_text.append(i)
        time.sleep(delay)
        print("".join(custom_text),end="\r")
    print("\n\n")


from smisch import running_os
from os import system
def clear_console(type="full"):
    if type == "full":
        if running_os == "win":
            system("cls")
        else:
            system("clear")
    elif type == "line":
        print(100*" ",end="\r\r")
    



import time

def animate_input(text,delay=0.05):
    from smisch import clear_console
    clear_console("full")
    custom_text = []
    for i in text:
        custom_text.append(i)
        time.sleep(delay)
        if len(text) != len(custom_text):
            print("".join(custom_text),end="\r")
        else:
            s = input(f"{text}")
            clear_console("full")
            return s